@@ -1,4 +1,4 @@
-from .croniter import croniter
+from croniter import croniter
 from .Logging import log, LogLevel
 
 
