@@ -23,6 +23,9 @@ from .dateHelpers import getUtcDate
 from .croniterHelpers import get_croniter
 from .redis import WorkerRedis
 import traceback
+# health check probe
+from threading import Thread
+from .healthCheckProbe import health_check_probe
 
 import functools
 
@@ -174,6 +177,7 @@ class ValiotWorker():
     """
 
     def __init__(self):
+        self.healthCheckThread = None
         self.queues = {}
         self.eventQueues = {}
         self.currentQueues = []
@@ -534,8 +538,8 @@ class ValiotWorker():
             'active': False,
             'endAt': getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
         }
-        lock, errors = self.gql.query(queries.get_queueLock, variables={"lockId": lock['id']})
-        if not lock:
+        current_lock, errors = self.gql.query(queries.get_queueLock, variables={"lockId": lock['id']})
+        if not current_lock:
             return True # lock already unlocked
         data, errors = self.gql.mutate(mutations.update_lock, variables)
         lock = __.get(data, 'result')
@@ -1026,7 +1030,7 @@ class ValiotWorker():
                 if self.workerQueueEnabled(queue):
                     if self.queue_locked(queue["name"]):
                         self.log(LogLevel.ERROR,
-                                    f"{queue['name']['name']} is LOCKED, postponing...")
+                                    f"{queue['name']} is LOCKED, postponing...")
                     else:
                         self.gql.mutate(
                             mutation=mutations.create_job,
@@ -1486,6 +1490,25 @@ class ValiotWorker():
             raise Exception('Worker not found')
         self.worker = worker
 
+    def startHealthCheck(self):
+        """This function starts the health check.
+        """
+        # making the thread daemon allows the main thread to exit even if the health check thread is still running
+        self.healthCheckThread = Thread(target=health_check_probe, daemon=True, name='health_check_probe', args=(self.log, self.loggingStyle))
+        self.healthCheckThread.start()
+        self.log(LogLevel.SUCCESS, 'Health check started')
+
+    def waitUntilWorkerIsReady(self):
+        """This function waits until the server is ready (avoid duplicate pods running jobs).
+        """
+        current_env = os.environ.get('ENV')
+        if current_env == 'dev':
+            self.log(LogLevel.WARNING, 'Skipping worker readiness check in dev environment')
+            return
+        initial_delay = os.environ.get('INITIAL_DELAY', 30)
+        self.log(LogLevel.INFO, f'Waiting {initial_delay} seconds before starting worker...')
+        time.sleep(int(initial_delay))
+
     def run(self, interval=1.0):
         """This function turns on the worker.
 
@@ -1496,6 +1519,8 @@ class ValiotWorker():
         self.context = mp.get_context('fork')
         self.getWorker()
         self.startLoggingLoop()
+        self.startHealthCheck()
+        self.waitUntilWorkerIsReady()
         self.abortStaleJobs()
         if (self.jobConfigMode == JobConfigMode.SYNC):
             self.updateAvailableQueues()
